==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/survey_client/l10n/cs.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "Průzkum používání",
    "Sent on: {on}" : "Odesláno: {on}",
    "An error occurred while sending your report." : "Při odesílání sestavy došlo k chybě.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Seznsm aplikací <em>(pro každou aplikaci: název, verze, povolený stav)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Databázové prostředí <em>(typ, verze, velikost databáze)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Informace o šifrování <em>(je to povoleno ?, jaký je výchozí modul)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Počet sdílení <em>(podle typu a nastavení oprávnění)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP prostředí <em>(verze, limit paměti, max. doba provedení, max. velikost souboru)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Podrobnosti o instanci serveru <em>(verze, použití memcache, stav blokování /náhledů/avatarů)</em>",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "Statistika <em>(počet: souborů, uživatelů, uložišť podle typu, komentářů a značek)</em>",
    "Help improve Nextcloud" : "Pomozte zlepšit Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Chcete nám pomoci zlepšit aplikaci Nextcloud poskytnutím některých anonymních údajů o vašem nastavení a použití? Můžete vše znovu kdykoli vypnout v nastavení administrace.",
    "Not now" : "Teď ne",
    "Send usage" : "Odeslat přehled",
    "Never" : "Nikdy",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Můžete nám pomoci zlepšit Nextcloud tím, že nám pošlete nějaké údaje o vašem aktuálním nastavení a použití.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Vaše soukromí bereme vážně. Odesílání dat je ve výchozím nastavení zakázáno a pokud se je rozhodnete zapnout, bude nejdříve anonymizováno a budete mít možnost vybrat, jaké věci sdílet. Po obdržení zprávy se předchozí odebere. Nahraje se čistý přehled a odstraní se všechna data aktuálně uložená na serveru.",
    "Send new report now" : "Odeslat nový přehled hned",
    "Send usage survey monthly" : "Odeslat přehled o používání měsíčně",
    "Data to send" : "Data k odeslání",
    "Last report" : "Poslední přehled",
    "Sent on: %s" : "Odeslán: %s",
    "App list <em>(for each app: name, version, is enabled?)</em>" : "Seznam aplikací <em>(pro každou aplikaci: název, verze, je povolena?)</em>",
    "Server instance details <em>(version, memcache used, locking/previews/avatars enabled?)</em>" : "Podrobnosti instance serveru <em>(verze, použití memcache, blokování/náhledy/avatary jsou povoleny?)</em>",
    "You can help us to improve Nextcloud be sending us some data about your current setup and usage." : "Můžete nám pomoci zlepšit Nextcloud a poslat nám data o vašem aktuálním nastavení a použití.",
    "We take your privacy seriously. The data are anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data are send and always see the last report send to us. When the server receives a new report of your instance, all entries from previous reports are removed. In case you disable one of the settings below, you can send a new report, to delete the data, that is currently stored on the server." : "Vaše soukromí bereme vážně. Data jsou anonymní a můžete je kdykoli povolit / zakázat, ve výchozím nastavení jsou vždy zakázána. Níže je také možné nastavit, jaká data se odesílají a vždy vidět, jak nám poslední zpráva byla odeslána. Když server obdrží nový přehled vaší instance, budou odebrány všechny položky z předchozích zpráv. V případě, že vypnete některá z níže uvedených nastavení, můžete odeslat nový přehled, který odstraní data, která jsou aktuálně uložena na serveru.",
    "You can help us to improve Nextcloud by sending us some data about your current setup and usage." : "Můžete nám pomoci zlepšit Nextcloud tím, že nám pošlete nějaké údaje o vašem aktuálním nastavení a použití.",
    "We take your privacy seriously. The data is anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data is sent and always see the last report sent to us. When the server receives a new report of your instance, all entries from previous reports are removed. If you disable one of the settings below, you can send a new report, which will delete the data that is currently stored on the server." : "Vaše soukromí breme vážně. Data jsou anonymní a můžete je kdykoli povolit / zskázat, ve výchozím nastavení jsou vždy zakázána. Níže můžete také nastavit, jaký druh dat je odeslán a vždy vidět poslední zprávu, která nám byla zaslána. Když server obdrží nový přehled vaší instance, budou odebrány všechny položky z předchozích zpráv. Pokud zakážete některá z níže uvedených nastavení, můžete odeslat nový přehled, který odstraní data, která jsou aktuálně uložena na serveru."
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/survey_client/l10n/cs.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "Průzkum používání",
    "An error occurred while sending your report." : "Při odesílání sestavy došlo k chybě.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Seznam aplikací <em>(pro každou aplikaci: název, verze, povolený stav)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Databázové prostředí <em>(typ, verze, velikost databáze)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Informace o šifrování <em>(je to povoleno?, jaký je výchozí modul)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Počet sdílení <em>(podle typu a nastavení oprávnění)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP prostředí <em>(verze, limit paměti, max. doba provedení, max. velikost souboru)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Podrobnosti o instanci serveru <em>(verze, použití memcache, stav blokování /náhledů/avatarů)</em>",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "Statistika <em>(počet: souborů, uživatelů, uložišť podle typu, komentářů a značek)</em>",
    "Help improve Nextcloud" : "Pomozte zlepšit Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Chcete nám pomoci zlepšit aplikaci Nextcloud poskytnutím některých anonymních údajů o vašem nastavení a použití? Můžete vše znovu kdykoli vypnout v nastavení administrace.",
    "Not now" : "Teď ne",
    "Send usage" : "Odeslat přehled",
    "Never" : "Nikdy",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Můžete nám pomoci zlepšit Nextcloud tím, že nám pošlete nějaké údaje o vašem aktuálním nastavení a použití.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Vaše soukromí bereme vážně. Odesílání dat je ve výchozím nastavení zakázáno a pokud se je rozhodnete zapnout, bude nejdříve anonymizováno a budete mít možnost vybrat, jaké věci sdílet. Po obdržení zprávy se předchozí odebere. Nahraje se čistý přehled a odstraní se všechna data aktuálně uložená na serveru.",
    "Send new report now" : "Odeslat nový přehled hned",
    "Send usage survey monthly" : "Odeslat přehled o používání měsíčně",
    "Data to send" : "Data k odeslání",
    "Last report" : "Poslední přehled",
    "Sent on: {on}" : "Odesláno: {on}",
    "App list <em>(for each app: name, version, is enabled?)</em>" : "Seznam aplikací <em>(pro každou aplikaci: název, verze, je povolena?)</em>",
    "Server instance details <em>(version, memcache used, locking/previews/avatars enabled?)</em>" : "Podrobnosti instance serveru <em>(verze, použití memcache, blokování/náhledy/avatary jsou povoleny?)</em>",
    "You can help us to improve Nextcloud by sending us some data about your current setup and usage." : "Můžete nám pomoci zlepšit Nextcloud tím, že nám pošlete nějaké údaje o vašem aktuálním nastavení a použití.",
    "We take your privacy seriously. The data is anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data is sent and always see the last report sent to us. When the server receives a new report of your instance, all entries from previous reports are removed. If you disable one of the settings below, you can send a new report, which will delete the data that is currently stored on the server." : "Vaše soukromí breme vážně. Data jsou anonymní a můžete je kdykoli povolit / zskázat, ve výchozím nastavení jsou vždy zakázána. Níže můžete také nastavit, jaký druh dat je odeslán a vždy vidět poslední zprávu, která nám byla zaslána. Když server obdrží nový přehled vaší instance, budou odebrány všechny položky z předchozích zpráv. Pokud zakážete některá z níže uvedených nastavení, můžete odeslat nový přehled, který odstraní data, která jsou aktuálně uložena na serveru.",
    "Sent on: %s" : "Odeslán: %s"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
